@@ -802,11 +802,13 @@ class Soil(SoilBaseModel):
     def _to_dgeoflow(self):
         from geolib.models.dgeoflow.internal import PersistableSoil as DGeoFlowSoil
 
+        self.set_all_stochastic_parameters()
+        
         kwargs = {
             "Id": self.id,
             "Name": self.name,
             "Code": self.code,
-            "HorizontalPermeability": self.storage_parameters.horizontal_permeability,
-            "VerticalPermeability": self.storage_parameters.vertical_permeability,
+            "HorizontalPermeability": self.storage_parameters.horizontal_permeability.mean,
+            "VerticalPermeability": self.storage_parameters.vertical_permeability.mean,
         }
         return self.__transfer_soil_dict_to_model(kwargs, DGeoFlowSoil())
